package it.davideorlandi.jtbtar;

import java.io.InputStream;

import com.ice.tar.TarInputStream;

/**
 * An estension of {@link TarInputStream} exposing the absolute record number.
 * @author Davide
 */
public class IndexedTarInputStream extends TarInputStream
{
    private int recordsPerBlock;

    /**
     * Constructor.
     * @param inputStream the input stream.
     */
    public IndexedTarInputStream(final InputStream inputStream)
    {
        super(inputStream);
        recordsPerBlock = buffer.getBlockSize() / buffer.getRecordSize();
    }

    /**
     * Returns the current absolute record number, useful to build an index as the -R opion does on
     * the unix tar.
     * @return absolute record number.
     */
    public long getAbsoluteRecordNumber()
    {
        return buffer.getCurrentRecordNum() + buffer.getCurrentBlockNum() * recordsPerBlock;
    }

}
