package it.davideorlandi.jtbtar;

import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * @author Davide
 */
public class LocaleManager
{
    /** localized message bundle */
    private static ResourceBundle bundle = null;

    /** base message bundle (used for messages missing from the localized bundle) */
    private static ResourceBundle fallBackBundle = null;

    static
    {
        setLocale(Locale.getDefault());
    }

    /**
     * Sets current language and loads the {@link ResourceBundle}.
     * @param newLocale new language.
     */
    public static final void setLocale(final Locale newLocale)
    {
        bundle = ResourceBundle.getBundle("locale/texts", newLocale);
        fallBackBundle = ResourceBundle.getBundle("locale/texts", Locale.ENGLISH);
    }

    /**
     * Works like {@link MessageFormat#format(String, Object...)} but looking fhe template string in
     * a localized bundle.
     * @param key key of the message.
     * @param arguments message arguments.
     * @return formatted string.
     */
    public static String format(final String key, final Object... arguments)
    {
        String template = null;
        try
        {
            template = bundle.getString(key);
        }
        catch (MissingResourceException mre)
        {
            try
            {
                template = fallBackBundle.getString(key);
            }
            catch (MissingResourceException mre2)
            {
                return "[missing text for: " + key + "]";
            }
        }

        return MessageFormat.format(template, arguments);
    }
}
