package it.davideorlandi.jtbtar;

/**
 * Maps a 0-100 progres into a bigger operation.
 */
public class PartitionProgressNotifier implements ProgressNotifier
{
    private final ProgressNotifier mappedNotifier;

    private final double scale;

    private final double offset;

    /**
     * Creates a {@link PartitionProgressNotifier} to map 0-100 progress of the specified notifier
     * into a bigger operation.
     * @param mappedNotifier progress notifier to map.
     * @param parts number of parts the bigger operation is made of.
     * @param partNumber zero-based index of this part in the bigger operation.
     */
    public PartitionProgressNotifier(final ProgressNotifier mappedNotifier, final int parts,
            final int partNumber)
    {
        this.mappedNotifier = mappedNotifier;
        this.scale = 1.0 / parts;
        this.offset = 100.0 * partNumber / parts;
    }

    /*
     * (non-Javadoc)
     * @see it.davideorlandi.jtbtar.ProgressNotifier#complete()
     */
    @Override
    public void complete()
    {
        mappedNotifier.complete();
    }

    /*
     * (non-Javadoc)
     * @see it.davideorlandi.jtbtar.ProgressNotifier#displayException(java.lang.Throwable)
     */
    @Override
    public void error(final Throwable exception)
    {
        mappedNotifier.error(exception);
    }

    /*
     * (non-Javadoc)
     * @see it.davideorlandi.jtbtar.ProgressNotifier#displayProgress(double, java.lang.String)
     */
    @Override
    public boolean displayProgress(final double progressPercent, final String note)
    {
        return mappedNotifier.displayProgress(progressPercent * scale + offset, note);
    }

}
