package it.davideorlandi.jtbtar;

/**
 * @author Davide
 */
public interface ProgressNotifier
{
    /**
     * Display a progress indication. It is always necessary to call {@link #complete()} even if the
     * task is at 100% or when aborting.
     * @param progressPercent 0.0=begin, 100.0=finished.
     * @param note description of current action; if null, the previous one will be used.
     * @return true=continue, false=abort.
     */
    public boolean displayProgress(double progressPercent, String note);

    /**
     * Display an exception. Caller will stop execution after that. This method should be called as
     * an <b>alternative</b> to {@link #complete()}.
     * @param exception throwable to be displayed.
     */
    public void error(Throwable exception);

    /**
     * Called when the task is completed. This method should be called as an <b>alternative</b> to
     * {@link #error(Throwable)}.
     */
    public void complete();
}
