package it.davideorlandi.jtbtar.ui;

import it.davideorlandi.jtbtar.ProgressNotifier;

/**
 * A long running task invoked from Swing. Relevant methods of the {@link ProgressNotifier} are
 * called when completing the task or when an exception occurs.
 * @author Davide
 */
public abstract class LongRunningTask extends Thread
{
    /**
     * {@link ProgressNotifier} to be used for progress indication.
     */
    protected ProgressNotifier notifier;

    /**
     * Constructor.
     * @param notifier notifier for this task.
     */
    public LongRunningTask(final ProgressNotifier notifier)
    {
        this.notifier = notifier;
    }

    /*
     * (non-Javadoc)
     * @see java.lang.Thread#run()
     */
    @Override
    public void run()
    {
        try
        {
            runnableCode();
            notifier.complete();
        }
        catch (Exception e)
        {
            notifier.error(e);
        }
    }

    /**
     * Code to be run. Can access the protected {@link #notifier} member.
     * @throws Exception generic error.
     */
    public abstract void runnableCode() throws Exception;

}
