package it.davideorlandi.jtbtar.ui;

import it.davideorlandi.jtbtar.LocaleManager;
import it.davideorlandi.jtbtar.TbtarEngine;

import java.util.prefs.Preferences;

import javax.swing.JTabbedPane;
import javax.swing.KeyStroke;

/**
 * Main application panel.
 * @author Davide
 */
public class MainPanel extends JTabbedPane
{
    /** atlas panel */
    private final AtlasPanel atlasPanel;

    /** map panel */
    private final MapPanel mapPanel;

    /**
     * Constructor.
     * @param engine application engine.
     */
    public MainPanel(final TbtarEngine engine)
    {
        super();

        this.atlasPanel = new AtlasPanel(engine);
        this.mapPanel = new MapPanel(engine);

        addTab(LocaleManager.format("ui.tab.atlas"), atlasPanel);
        setMnemonicAt(
                0,
                KeyStroke.getKeyStroke(LocaleManager.format("ui.tab.atlas.mnemonic")).getKeyCode());
        addTab(LocaleManager.format("ui.tab.map"), mapPanel);
        setMnemonicAt(
                1,
                KeyStroke.getKeyStroke(LocaleManager.format("ui.tab.map.mnemonic")).getKeyCode());
    }

    /**
     * Read the preferences for this panel.
     * @param prefs preferences object for the application.
     */
    public void readPreferences(final Preferences prefs)
    {
        atlasPanel.readPreferences(prefs);
        mapPanel.readPreferences(prefs);
        setSelectedIndex(prefs.getInt(PreferenceKeys.SELECTED_TAB, 0));
    }

    /**
     * Writes the preferences for this panel.
     * @param prefs preferences object for the application.
     */
    public void writePreferences(final Preferences prefs)
    {
        atlasPanel.writePreferences(prefs);
        mapPanel.writePreferences(prefs);
        prefs.putInt(PreferenceKeys.SELECTED_TAB, getSelectedIndex());
    }

    /**
     * Enable or disable controls.
     * @param enabled true=enabled, false=disabled.
     */
    public void setControlsEnabled(final boolean enabled)
    {
        atlasPanel.setControlsEnabled(enabled);
        mapPanel.setControlsEnabled(enabled);
        atlasPanel.setEnabled(enabled);
        mapPanel.setEnabled(enabled);
        setEnabled(enabled);
    }
}
