package it.davideorlandi.jtbtar.ui;

import it.davideorlandi.jtbtar.LocaleManager;
import it.davideorlandi.jtbtar.TbtarEngine;

import java.awt.Dimension;
import java.awt.HeadlessException;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.prefs.Preferences;

import javax.swing.Box;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.KeyStroke;

/**
 * @author Davide
 */
public class MainWindow extends JFrame
{

    /** user preferences */
    final Preferences prefs = Preferences.userNodeForPackage(getClass());

    /** main engine for tar/untar */
    final TbtarEngine engine = new TbtarEngine();

    /** main panel for the application */
    final MainPanel mainPanel;

    /**
     * Costruttore.
     * @throws HeadlessException
     */
    public MainWindow() throws HeadlessException
    {
        final JFrame myself = this;
        setTitle(LocaleManager.format("ui.application.name"));
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        mainPanel = new MainPanel(engine);
        mainPanel.readPreferences(prefs);

        getContentPane().add(mainPanel);

        JMenuBar menuBar = new JMenuBar();
        JMenu menuAbout = new JMenu(LocaleManager.format("ui.menu.about"));
        menuAbout.setMnemonic(KeyStroke.getKeyStroke(LocaleManager.format("ui.menu.about.mnemonic")).getKeyCode());
        menuBar.add(Box.createHorizontalGlue());
        menuBar.add(menuAbout);
        JMenuItem menuItemAbout = new JMenuItem(LocaleManager.format("ui.menuitem.about"));
        menuItemAbout.setMnemonic(KeyStroke.getKeyStroke(
                LocaleManager.format("ui.menuitem.about.mnemonic")).getKeyCode());
        menuAbout.add(menuItemAbout);
        menuItemAbout.addActionListener(new ActionListener()
        {
            @Override
            public void actionPerformed(final java.awt.event.ActionEvent e)
            {
                new AboutDialog(myself, true).setVisible(true);
            }
        });

        setJMenuBar(menuBar);

        pack();

        // note: height is not saved in the preferences
        setSize(prefs.getInt(PreferenceKeys.WINDOW_WIDTH, getSize().width), getSize().height);
        setLocation(prefs.getInt(PreferenceKeys.WINDOW_POSITION_X, getLocation().x), prefs.getInt(
                PreferenceKeys.WINDOW_POSITION_Y, getLocation().y));
        setMinimumSize(new Dimension(200, 100));

        addWindowListener(new WindowAdapter()
        {
            @Override
            public void windowClosing(final WindowEvent e)
            {
                // set preferences at exit
                prefs.putInt(PreferenceKeys.WINDOW_WIDTH, getSize().width);
                prefs.putInt(PreferenceKeys.WINDOW_POSITION_X, getLocation().x);
                prefs.putInt(PreferenceKeys.WINDOW_POSITION_Y, getLocation().y);

                mainPanel.writePreferences(prefs);
            }
        });
    }

}
