package it.davideorlandi.jtbtar.ui;

import it.davideorlandi.jtbtar.LocaleManager;
import it.davideorlandi.jtbtar.ProgressNotifier;

import java.awt.Component;

import javax.swing.JOptionPane;
import javax.swing.ProgressMonitor;

/**
 * Displays the current progress using a {@link ProgressMonitor}.
 */
public class UIProgressNotifier implements ProgressNotifier
{

    private static final int MAX = 65536;

    private ProgressMonitor monitor;

    private Component parentComponent;

    private CanBeDisabled controls;

    /**
     * Constructor.
     * @param taskDescription description of the task.
     * @param parentComponent parent component of the ProgressMonitor.
     * @param controls if not null, {@link CanBeDisabled#setControlsEnabled(boolean)} will be called
     *        at {@link #complete()} to enable the controls.
     */
    public UIProgressNotifier(final String taskDescription, final Component parentComponent,
            final CanBeDisabled controls)
    {
        this.parentComponent = parentComponent;
        this.monitor = new ProgressMonitor(this.parentComponent, taskDescription,
                LocaleManager.format("ui.progress.initializing"), 0, MAX);
        this.controls = controls;
        monitor.setMillisToPopup(0);
        monitor.setMillisToDecideToPopup(0);
    }

    /*
     * (non-Javadoc)
     * @see it.davideorlandi.jtbtar.ProgressNotifier#displayException(java.lang.Throwable)
     */
    @Override
    public void error(final Throwable exception)
    {
        UIUtilities.handleException(exception, parentComponent);
        monitor.close();
        if (controls != null)
        {
            controls.setControlsEnabled(true);
        }
    }

    /*
     * (non-Javadoc)
     * @see it.davideorlandi.jtbtar.ProgressNotifier#displayProgress(float, java.lang.String)
     */
    @Override
    public boolean displayProgress(final double progressPercent, final String note)
    {
        int intProgress = (int) (progressPercent * MAX / 100.0);
        monitor.setProgress(intProgress);
        if (note != null)
            monitor.setNote(note);
        return ! monitor.isCanceled();
    }

    /*
     * (non-Javadoc)
     * @see it.davideorlandi.jtbtar.ProgressNotifier#complete()
     */
    @Override
    public void complete()
    {
        monitor.close();
        if (controls != null)
        {
            JOptionPane.showMessageDialog(parentComponent,
                    LocaleManager.format("ui.completed.message"),
                    LocaleManager.format("ui.completed.title"), JOptionPane.INFORMATION_MESSAGE);
            controls.setControlsEnabled(true);
        }
    }

}
